del /S /Q ruamel.yaml.egg-info
del /S /Q build
c:\python\2.7\python.exe setup.py bdist_wheel
c:\python\2.7-32\python.exe setup.py bdist_wheel
c:\python\2.6\python.exe setup.py bdist_wheel
c:\python\2.6-32\python.exe setup.py bdist_wheel
c:\python\3.4\python.exe setup.py bdist_wheel
c:\python\3.4-32\python.exe setup.py bdist_wheel
c:\python\3.3\python.exe setup.py bdist_wheel
c:\python\3.3-32\python.exe setup.py bdist_wheel
c:\pypy2\2.5\pypy-2.5.1-win32\pypy.exe setup.py bdist_wheel
